@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# $Id: all_errors.pm 2677 2009-09-07 19:13:43Z rcaputo $
+# vim: ts=2 sw=2 expandtab
 
 # Tests error conditions.  This has to be a separate test since it
 # depends on ASSERT_DEFAULT being 0.  All the other tests enable it.
@@ -8,8 +8,11 @@ use strict;
 use lib qw(./mylib ../mylib);
 
 sub POE::Kernel::ASSERT_DEFAULT () { 0 }
-sub POE::Kernel::TRACE_DEFAULT  () { 1 }
-sub POE::Kernel::TRACE_FILENAME () { "./test-output.err" }
+
+BEGIN {
+  package POE::Kernel;
+  use constant TRACE_DEFAULT => exists($INC{'Devel/Cover.pm'});
+}
 
 # use Test::More;
 
@@ -46,7 +49,7 @@ print "1..0 # Skip most of these should move into other test files\n";
 #
 #  # Test that errors occur when multiple event loops are enabled.
 #
-#  if ($^O eq 'MSWin32') {
+#  if ($^O eq 'MSWin32' and not $ENV{POE_DANTIC}) {
 #    for (1..3) {
 #      print "ok $_ # skipped: This test crashes ActiveState Perl.\n";
 #    }
@@ -203,7 +206,7 @@ print "1..0 # Skip most of these should move into other test files\n";
 #  local $SIG{__WARN__} = sub { $warnings++; };
 #
 #  # Grar!  No UNIX sockets on Windows.
-#  if ($^O eq 'MSWin32') {
+#  if ($^O eq 'MSWin32' and not $ENV{POE_DANTIC}) {
 #    print "ok 21 # skipped: $^O does not support listen on unbound sockets.\n";
 #    print "ok 22 # skipped: $^O does not support UNIX sockets.\n";
 #  }
@@ -386,7 +389,7 @@ print "1..0 # Skip most of these should move into other test files\n";
 #print 'not ' unless defined $@ and length $@;
 #print "ok 47\n";
 #
-#if ($^O ne 'MSWin32' and $^O ne 'MacOS') {
+#if (($^O ne 'MSWin32' and $^O ne 'MacOS') or $ENV{POE_DANTIC}) {
 #  require POE::Wheel::Run;
 #  POE::Wheel::Run->import();
 #
